@@ -2,23 +2,23 @@ import importlib
 import math
 import os
 
-import tornado.options
+from tornado.options import options
 
 
 class Ks3Oss:
     def __init__(self, **kwargs):
         if not kwargs.get("access_key_id"):
-            kwargs.update({"access_key_id": tornado.options.options.ks3_connect_config.get("access_key_id")})
+            kwargs.update({"access_key_id": options.ks3_connect_config.get("access_key_id")})
         if not kwargs.get("access_key_secret"):
-            kwargs.update({"access_key_secret": tornado.options.options.ks3_connect_config.get("access_key_secret")})
+            kwargs.update({"access_key_secret": options.ks3_connect_config.get("access_key_secret")})
         if not kwargs.get("host"):
-            kwargs.update({"host": tornado.options.options.ks3_connect_config.get("host")})
+            kwargs.update({"host": options.ks3_connect_config.get("host")})
         if not kwargs.get("is_secure"):
-            if tornado.options.options.ks3_connect_config.get("is_secure"):
-                kwargs.update({"is_secure": tornado.options.options.ks3_connect_config.get("is_secure")})
+            if options.ks3_connect_config.get("is_secure"):
+                kwargs.update({"is_secure": options.ks3_connect_config.get("is_secure")})
         bucket_name = kwargs.pop("bucket_name", None)
         if bucket_name is None:
-            bucket_name = tornado.options.options.ks3_connect_config.get("bucket_name")
+            bucket_name = options.ks3_connect_config.get("bucket_name")
         try:
             ks3_connection = importlib.import_module("ks3.connection")
         except ImportError:
