@@ -6,7 +6,7 @@ import threading
 from tornado.options import define, options
 from tornado.web import RequestHandler
 
-from lesscode.utils.doc.interface_doc_handler import parser_swagger
+from lesscode.utils.doc.interface_doc import parser_swagger
 from lesscode.utils.upms_util import upms_register, resource_register
 from lesscode.web.business_exception import BusinessException
 from lesscode.web.status_code import StatusCode
